@@ -1,7 +1,7 @@
 """
 Type annotations for compute-optimizer service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/literals.html)
 
 Usage::
 
@@ -21,9 +21,12 @@ else:
 
 __all__ = (
     "CpuVendorArchitectureType",
+    "CurrencyType",
+    "CurrentPerformanceRiskType",
     "EBSFilterNameType",
     "EBSFindingType",
     "EBSMetricNameType",
+    "EnhancedInfrastructureMetricsType",
     "EnrollmentFilterNameType",
     "ExportableAutoScalingGroupFieldType",
     "ExportableInstanceFieldType",
@@ -33,6 +36,8 @@ __all__ = (
     "FilterNameType",
     "FindingReasonCodeType",
     "FindingType",
+    "InferredWorkloadTypeType",
+    "InferredWorkloadTypesPreferenceType",
     "InstanceRecommendationFindingReasonCodeType",
     "JobFilterNameType",
     "JobStatusType",
@@ -45,17 +50,20 @@ __all__ = (
     "LambdaFunctionRecommendationFindingType",
     "MetricNameType",
     "MetricStatisticType",
+    "MigrationEffortType",
     "PlatformDifferenceType",
+    "RecommendationPreferenceNameType",
     "RecommendationSourceTypeType",
     "ResourceTypeType",
+    "ScopeNameType",
     "StatusType",
-    "ComputeOptimizerServiceName",
     "ServiceName",
-    "ResourceServiceName",
 )
 
 
 CpuVendorArchitectureType = Literal["AWS_ARM64", "CURRENT"]
+CurrencyType = Literal["CNY", "USD"]
+CurrentPerformanceRiskType = Literal["High", "Low", "Medium", "VeryLow"]
 EBSFilterNameType = Literal["Finding"]
 EBSFindingType = Literal["NotOptimized", "Optimized"]
 EBSMetricNameType = Literal[
@@ -64,6 +72,7 @@ EBSMetricNameType = Literal[
     "VolumeWriteBytesPerSecond",
     "VolumeWriteOpsPerSecond",
 ]
+EnhancedInfrastructureMetricsType = Literal["Active", "Inactive"]
 EnrollmentFilterNameType = Literal["Status"]
 ExportableAutoScalingGroupFieldType = Literal[
     "AccountId",
@@ -76,23 +85,32 @@ ExportableAutoScalingGroupFieldType = Literal[
     "CurrentMemory",
     "CurrentNetwork",
     "CurrentOnDemandPrice",
+    "CurrentPerformanceRisk",
     "CurrentStandardOneYearNoUpfrontReservedPrice",
     "CurrentStandardThreeYearNoUpfrontReservedPrice",
     "CurrentStorage",
     "CurrentVCpus",
+    "EffectiveRecommendationPreferencesCpuVendorArchitectures",
+    "EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics",
+    "EffectiveRecommendationPreferencesInferredWorkloadTypes",
     "Finding",
+    "InferredWorkloadTypes",
     "LastRefreshTimestamp",
     "LookbackPeriodInDays",
     "RecommendationOptionsConfigurationDesiredCapacity",
     "RecommendationOptionsConfigurationInstanceType",
     "RecommendationOptionsConfigurationMaxSize",
     "RecommendationOptionsConfigurationMinSize",
+    "RecommendationOptionsEstimatedMonthlySavingsCurrency",
+    "RecommendationOptionsEstimatedMonthlySavingsValue",
     "RecommendationOptionsMemory",
+    "RecommendationOptionsMigrationEffort",
     "RecommendationOptionsNetwork",
     "RecommendationOptionsOnDemandPrice",
     "RecommendationOptionsPerformanceRisk",
     "RecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
     "RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum",
+    "RecommendationOptionsSavingsOpportunityPercentage",
     "RecommendationOptionsStandardOneYearNoUpfrontReservedPrice",
     "RecommendationOptionsStandardThreeYearNoUpfrontReservedPrice",
     "RecommendationOptionsStorage",
@@ -118,24 +136,33 @@ ExportableInstanceFieldType = Literal[
     "CurrentMemory",
     "CurrentNetwork",
     "CurrentOnDemandPrice",
+    "CurrentPerformanceRisk",
     "CurrentStandardOneYearNoUpfrontReservedPrice",
     "CurrentStandardThreeYearNoUpfrontReservedPrice",
     "CurrentStorage",
     "CurrentVCpus",
+    "EffectiveRecommendationPreferencesCpuVendorArchitectures",
+    "EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics",
+    "EffectiveRecommendationPreferencesInferredWorkloadTypes",
     "Finding",
     "FindingReasonCodes",
+    "InferredWorkloadTypes",
     "InstanceArn",
     "InstanceName",
     "LastRefreshTimestamp",
     "LookbackPeriodInDays",
+    "RecommendationOptionsEstimatedMonthlySavingsCurrency",
+    "RecommendationOptionsEstimatedMonthlySavingsValue",
     "RecommendationOptionsInstanceType",
     "RecommendationOptionsMemory",
+    "RecommendationOptionsMigrationEffort",
     "RecommendationOptionsNetwork",
     "RecommendationOptionsOnDemandPrice",
     "RecommendationOptionsPerformanceRisk",
     "RecommendationOptionsPlatformDifferences",
     "RecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
     "RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum",
+    "RecommendationOptionsSavingsOpportunityPercentage",
     "RecommendationOptionsStandardOneYearNoUpfrontReservedPrice",
     "RecommendationOptionsStandardThreeYearNoUpfrontReservedPrice",
     "RecommendationOptionsStorage",
@@ -163,6 +190,7 @@ ExportableLambdaFunctionFieldType = Literal[
     "CurrentConfigurationTimeout",
     "CurrentCostAverage",
     "CurrentCostTotal",
+    "CurrentPerformanceRisk",
     "Finding",
     "FindingReasonCodes",
     "FunctionArn",
@@ -173,9 +201,12 @@ ExportableLambdaFunctionFieldType = Literal[
     "RecommendationOptionsConfigurationMemorySize",
     "RecommendationOptionsCostHigh",
     "RecommendationOptionsCostLow",
+    "RecommendationOptionsEstimatedMonthlySavingsCurrency",
+    "RecommendationOptionsEstimatedMonthlySavingsValue",
     "RecommendationOptionsProjectedUtilizationMetricsDurationExpected",
     "RecommendationOptionsProjectedUtilizationMetricsDurationLowerBound",
     "RecommendationOptionsProjectedUtilizationMetricsDurationUpperBound",
+    "RecommendationOptionsSavingsOpportunityPercentage",
     "UtilizationMetricsDurationAverage",
     "UtilizationMetricsDurationMaximum",
     "UtilizationMetricsMemoryAverage",
@@ -190,6 +221,7 @@ ExportableVolumeFieldType = Literal[
     "CurrentConfigurationVolumeSize",
     "CurrentConfigurationVolumeType",
     "CurrentMonthlyPrice",
+    "CurrentPerformanceRisk",
     "Finding",
     "LastRefreshTimestamp",
     "LookbackPeriodInDays",
@@ -199,8 +231,11 @@ ExportableVolumeFieldType = Literal[
     "RecommendationOptionsConfigurationVolumeBurstThroughput",
     "RecommendationOptionsConfigurationVolumeSize",
     "RecommendationOptionsConfigurationVolumeType",
+    "RecommendationOptionsEstimatedMonthlySavingsCurrency",
+    "RecommendationOptionsEstimatedMonthlySavingsValue",
     "RecommendationOptionsMonthlyPrice",
     "RecommendationOptionsPerformanceRisk",
+    "RecommendationOptionsSavingsOpportunityPercentage",
     "UtilizationMetricsVolumeReadBytesPerSecondMaximum",
     "UtilizationMetricsVolumeReadOpsPerSecondMaximum",
     "UtilizationMetricsVolumeWriteBytesPerSecondMaximum",
@@ -211,6 +246,10 @@ FileFormatType = Literal["Csv"]
 FilterNameType = Literal["Finding", "FindingReasonCodes", "RecommendationSourceType"]
 FindingReasonCodeType = Literal["MemoryOverprovisioned", "MemoryUnderprovisioned"]
 FindingType = Literal["NotOptimized", "Optimized", "Overprovisioned", "Underprovisioned"]
+InferredWorkloadTypeType = Literal[
+    "AmazonEmr", "ApacheCassandra", "ApacheHadoop", "Memcached", "Nginx", "PostgreSql", "Redis"
+]
+InferredWorkloadTypesPreferenceType = Literal["Active", "Inactive"]
 InstanceRecommendationFindingReasonCodeType = Literal[
     "CPUOverprovisioned",
     "CPUUnderprovisioned",
@@ -257,6 +296,7 @@ MetricNameType = Literal[
     "NETWORK_PACKETS_OUT_PER_SECOND",
 ]
 MetricStatisticType = Literal["Average", "Maximum"]
+MigrationEffortType = Literal["High", "Low", "Medium", "VeryLow"]
 PlatformDifferenceType = Literal[
     "Architecture",
     "Hypervisor",
@@ -265,12 +305,15 @@ PlatformDifferenceType = Literal[
     "StorageInterface",
     "VirtualizationType",
 ]
+RecommendationPreferenceNameType = Literal["EnhancedInfrastructureMetrics", "InferredWorkloadTypes"]
 RecommendationSourceTypeType = Literal[
     "AutoScalingGroup", "EbsVolume", "Ec2Instance", "LambdaFunction"
 ]
-ResourceTypeType = Literal["AutoScalingGroup", "EbsVolume", "Ec2Instance", "LambdaFunction"]
+ResourceTypeType = Literal[
+    "AutoScalingGroup", "EbsVolume", "Ec2Instance", "LambdaFunction", "NotApplicable"
+]
+ScopeNameType = Literal["AccountId", "Organization", "ResourceArn"]
 StatusType = Literal["Active", "Failed", "Inactive", "Pending"]
-ComputeOptimizerServiceName = Literal["compute-optimizer"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -280,10 +323,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -298,6 +343,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -352,6 +398,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -373,6 +420,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -399,6 +447,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -412,6 +461,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -457,7 +507,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -486,11 +538,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -500,6 +554,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -557,17 +612,6 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
