@@ -1,7 +1,7 @@
 """
 Type annotations for compute-optimizer service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/type_defs.html)
 
 Usage::
 
@@ -15,12 +15,13 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
-from typing_extensions import NotRequired
-
 from .literals import (
     CpuVendorArchitectureType,
+    CurrencyType,
+    CurrentPerformanceRiskType,
     EBSFindingType,
     EBSMetricNameType,
+    EnhancedInfrastructureMetricsType,
     ExportableAutoScalingGroupFieldType,
     ExportableInstanceFieldType,
     ExportableLambdaFunctionFieldType,
@@ -28,6 +29,8 @@ from .literals import (
     FilterNameType,
     FindingReasonCodeType,
     FindingType,
+    InferredWorkloadTypesPreferenceType,
+    InferredWorkloadTypeType,
     InstanceRecommendationFindingReasonCodeType,
     JobFilterNameType,
     JobStatusType,
@@ -39,9 +42,12 @@ from .literals import (
     LambdaFunctionRecommendationFindingType,
     MetricNameType,
     MetricStatisticType,
+    MigrationEffortType,
     PlatformDifferenceType,
+    RecommendationPreferenceNameType,
     RecommendationSourceTypeType,
     ResourceTypeType,
+    ScopeNameType,
     StatusType,
 )
 
@@ -60,11 +66,15 @@ __all__ = (
     "AutoScalingGroupConfigurationTypeDef",
     "AutoScalingGroupRecommendationOptionTypeDef",
     "AutoScalingGroupRecommendationTypeDef",
+    "CurrentPerformanceRiskRatingsTypeDef",
+    "DeleteRecommendationPreferencesRequestRequestTypeDef",
     "DescribeRecommendationExportJobsRequestRequestTypeDef",
     "DescribeRecommendationExportJobsResponseTypeDef",
     "EBSFilterTypeDef",
     "EBSUtilizationMetricTypeDef",
+    "EffectiveRecommendationPreferencesTypeDef",
     "EnrollmentFilterTypeDef",
+    "EstimatedMonthlySavingsTypeDef",
     "ExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     "ExportAutoScalingGroupRecommendationsResponseTypeDef",
     "ExportDestinationTypeDef",
@@ -83,12 +93,16 @@ __all__ = (
     "GetEC2InstanceRecommendationsResponseTypeDef",
     "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
+    "GetEffectiveRecommendationPreferencesRequestRequestTypeDef",
+    "GetEffectiveRecommendationPreferencesResponseTypeDef",
     "GetEnrollmentStatusResponseTypeDef",
     "GetEnrollmentStatusesForOrganizationRequestRequestTypeDef",
     "GetEnrollmentStatusesForOrganizationResponseTypeDef",
     "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
     "GetLambdaFunctionRecommendationsResponseTypeDef",
     "GetRecommendationErrorTypeDef",
+    "GetRecommendationPreferencesRequestRequestTypeDef",
+    "GetRecommendationPreferencesResponseTypeDef",
     "GetRecommendationSummariesRequestRequestTypeDef",
     "GetRecommendationSummariesResponseTypeDef",
     "InstanceRecommendationOptionTypeDef",
@@ -100,8 +114,10 @@ __all__ = (
     "LambdaFunctionRecommendationTypeDef",
     "LambdaFunctionUtilizationMetricTypeDef",
     "ProjectedMetricTypeDef",
+    "PutRecommendationPreferencesRequestRequestTypeDef",
     "ReasonCodeSummaryTypeDef",
     "RecommendationExportJobTypeDef",
+    "RecommendationPreferencesDetailTypeDef",
     "RecommendationPreferencesTypeDef",
     "RecommendationSourceTypeDef",
     "RecommendationSummaryTypeDef",
@@ -109,6 +125,8 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "S3DestinationConfigTypeDef",
     "S3DestinationTypeDef",
+    "SavingsOpportunityTypeDef",
+    "ScopeTypeDef",
     "SummaryTypeDef",
     "UpdateEnrollmentStatusRequestRequestTypeDef",
     "UpdateEnrollmentStatusResponseTypeDef",
@@ -147,6 +165,8 @@ AutoScalingGroupRecommendationOptionTypeDef = TypedDict(
         "projectedUtilizationMetrics": List["UtilizationMetricTypeDef"],
         "performanceRisk": float,
         "rank": int,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "migrationEffort": MigrationEffortType,
     },
     total=False,
 )
@@ -163,10 +183,47 @@ AutoScalingGroupRecommendationTypeDef = TypedDict(
         "currentConfiguration": "AutoScalingGroupConfigurationTypeDef",
         "recommendationOptions": List["AutoScalingGroupRecommendationOptionTypeDef"],
         "lastRefreshTimestamp": datetime,
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
+        "effectiveRecommendationPreferences": "EffectiveRecommendationPreferencesTypeDef",
+        "inferredWorkloadTypes": List[InferredWorkloadTypeType],
     },
     total=False,
 )
 
+CurrentPerformanceRiskRatingsTypeDef = TypedDict(
+    "CurrentPerformanceRiskRatingsTypeDef",
+    {
+        "high": int,
+        "medium": int,
+        "low": int,
+        "veryLow": int,
+    },
+    total=False,
+)
+
+_RequiredDeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "resourceType": ResourceTypeType,
+        "recommendationPreferenceNames": Sequence[RecommendationPreferenceNameType],
+    },
+)
+_OptionalDeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+    },
+    total=False,
+)
+
+
+class DeleteRecommendationPreferencesRequestRequestTypeDef(
+    _RequiredDeleteRecommendationPreferencesRequestRequestTypeDef,
+    _OptionalDeleteRecommendationPreferencesRequestRequestTypeDef,
+):
+    pass
+
+
 DescribeRecommendationExportJobsRequestRequestTypeDef = TypedDict(
     "DescribeRecommendationExportJobsRequestRequestTypeDef",
     {
@@ -206,6 +263,16 @@ EBSUtilizationMetricTypeDef = TypedDict(
     total=False,
 )
 
+EffectiveRecommendationPreferencesTypeDef = TypedDict(
+    "EffectiveRecommendationPreferencesTypeDef",
+    {
+        "cpuVendorArchitectures": List[CpuVendorArchitectureType],
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
+    },
+    total=False,
+)
+
 EnrollmentFilterTypeDef = TypedDict(
     "EnrollmentFilterTypeDef",
     {
@@ -215,6 +282,15 @@ EnrollmentFilterTypeDef = TypedDict(
     total=False,
 )
 
+EstimatedMonthlySavingsTypeDef = TypedDict(
+    "EstimatedMonthlySavingsTypeDef",
+    {
+        "currency": CurrencyType,
+        "value": float,
+    },
+    total=False,
+)
+
 _RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
     "_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
@@ -476,6 +552,21 @@ GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
     },
 )
 
+GetEffectiveRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "GetEffectiveRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
+GetEffectiveRecommendationPreferencesResponseTypeDef = TypedDict(
+    "GetEffectiveRecommendationPreferencesResponseTypeDef",
+    {
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetEnrollmentStatusResponseTypeDef = TypedDict(
     "GetEnrollmentStatusResponseTypeDef",
     {
@@ -538,6 +629,39 @@ GetRecommendationErrorTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredGetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "resourceType": ResourceTypeType,
+    },
+)
+_OptionalGetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class GetRecommendationPreferencesRequestRequestTypeDef(
+    _RequiredGetRecommendationPreferencesRequestRequestTypeDef,
+    _OptionalGetRecommendationPreferencesRequestRequestTypeDef,
+):
+    pass
+
+
+GetRecommendationPreferencesResponseTypeDef = TypedDict(
+    "GetRecommendationPreferencesResponseTypeDef",
+    {
+        "nextToken": str,
+        "recommendationPreferencesDetails": List["RecommendationPreferencesDetailTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetRecommendationSummariesRequestRequestTypeDef = TypedDict(
     "GetRecommendationSummariesRequestRequestTypeDef",
     {
@@ -565,6 +689,8 @@ InstanceRecommendationOptionTypeDef = TypedDict(
         "platformDifferences": List[PlatformDifferenceType],
         "performanceRisk": float,
         "rank": int,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "migrationEffort": MigrationEffortType,
     },
     total=False,
 )
@@ -583,6 +709,9 @@ InstanceRecommendationTypeDef = TypedDict(
         "recommendationOptions": List["InstanceRecommendationOptionTypeDef"],
         "recommendationSources": List["RecommendationSourceTypeDef"],
         "lastRefreshTimestamp": datetime,
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
+        "effectiveRecommendationPreferences": "EffectiveRecommendationPreferencesTypeDef",
+        "inferredWorkloadTypes": List[InferredWorkloadTypeType],
     },
     total=False,
 )
@@ -612,6 +741,7 @@ LambdaFunctionMemoryRecommendationOptionTypeDef = TypedDict(
         "rank": int,
         "memorySize": int,
         "projectedUtilizationMetrics": List["LambdaFunctionMemoryProjectedMetricTypeDef"],
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
     },
     total=False,
 )
@@ -639,6 +769,7 @@ LambdaFunctionRecommendationTypeDef = TypedDict(
         "finding": LambdaFunctionRecommendationFindingType,
         "findingReasonCodes": List[LambdaFunctionRecommendationFindingReasonCodeType],
         "memorySizeRecommendationOptions": List["LambdaFunctionMemoryRecommendationOptionTypeDef"],
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
     },
     total=False,
 )
@@ -663,6 +794,30 @@ ProjectedMetricTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredPutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredPutRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "resourceType": ResourceTypeType,
+    },
+)
+_OptionalPutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalPutRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
+    },
+    total=False,
+)
+
+
+class PutRecommendationPreferencesRequestRequestTypeDef(
+    _RequiredPutRecommendationPreferencesRequestRequestTypeDef,
+    _OptionalPutRecommendationPreferencesRequestRequestTypeDef,
+):
+    pass
+
+
 ReasonCodeSummaryTypeDef = TypedDict(
     "ReasonCodeSummaryTypeDef",
     {
@@ -686,6 +841,17 @@ RecommendationExportJobTypeDef = TypedDict(
     total=False,
 )
 
+RecommendationPreferencesDetailTypeDef = TypedDict(
+    "RecommendationPreferencesDetailTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+        "resourceType": ResourceTypeType,
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
+    },
+    total=False,
+)
+
 RecommendationPreferencesTypeDef = TypedDict(
     "RecommendationPreferencesTypeDef",
     {
@@ -709,6 +875,8 @@ RecommendationSummaryTypeDef = TypedDict(
         "summaries": List["SummaryTypeDef"],
         "recommendationResourceType": RecommendationSourceTypeType,
         "accountId": str,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "currentPerformanceRiskRatings": "CurrentPerformanceRiskRatingsTypeDef",
     },
     total=False,
 )
@@ -753,6 +921,24 @@ S3DestinationTypeDef = TypedDict(
     total=False,
 )
 
+SavingsOpportunityTypeDef = TypedDict(
+    "SavingsOpportunityTypeDef",
+    {
+        "savingsOpportunityPercentage": float,
+        "estimatedMonthlySavings": "EstimatedMonthlySavingsTypeDef",
+    },
+    total=False,
+)
+
+ScopeTypeDef = TypedDict(
+    "ScopeTypeDef",
+    {
+        "name": ScopeNameType,
+        "value": str,
+    },
+    total=False,
+)
+
 SummaryTypeDef = TypedDict(
     "SummaryTypeDef",
     {
@@ -823,6 +1009,7 @@ VolumeRecommendationOptionTypeDef = TypedDict(
         "configuration": "VolumeConfigurationTypeDef",
         "performanceRisk": float,
         "rank": int,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
     },
     total=False,
 )
@@ -838,6 +1025,7 @@ VolumeRecommendationTypeDef = TypedDict(
         "lookBackPeriodInDays": float,
         "volumeRecommendationOptions": List["VolumeRecommendationOptionTypeDef"],
         "lastRefreshTimestamp": datetime,
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
     },
     total=False,
 )
